@@ -2,8 +2,8 @@
 
 #
 # dbcolscorrelate.pm
-# Copyright (C) 1998-2008 by John Heidemann <johnh@isi.edu>
-# $Id$
+# Copyright (C) 1998-2015 by John Heidemann <johnh@isi.edu>
+# $Id: bdcf1da03251b46bded7f59984e64e7f5060ae46 $
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -141,7 +141,8 @@ end_standard_fsdb_options
 =head1 SEE ALSO
 
 L<Fsdb>,
-L<dbcolstatscores>
+L<dbcolstatscores>,
+L<dbcolsregression>.
 
 
 =head1 CLASS FUNCTIONS
@@ -392,7 +393,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2015 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
