@@ -31,6 +31,8 @@ When a null value is given, empty fields at the beginning and end of
 lines are suppressed (like perl split).  Unlike perl, if ALL fields
 are empty, we generate one (and not zero) empty fields.
 
+The inverse of this commend is L<dbfilepivot>.
+
 
 =head1 OPTIONS
 
@@ -135,6 +137,7 @@ L<Fsdb(1)>.
 L<dbcolmerge(1)>.
 L<dbcolsplittocols(1)>.
 L<dbcolrename(1)>.
+L<dbfilepvot(1)>.
 
 
 =head1 CLASS FUNCTIONS
