@@ -2,8 +2,8 @@
 
 #
 # dbcolsregression.pm
-# Copyright (C) 1997-2008 by John Heidemann <johnh@isi.edu>
-# $Id$
+# Copyright (C) 1997-2015 by John Heidemann <johnh@isi.edu>
+# $Id: 43fd25b3a4a5ea88ef37b0bb42c578f9cd848703 $
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -113,7 +113,7 @@ end_standard_fsdb_options
     #  | dblistize
 
 Sample data from 
-Lhttp://people.hofstra.edu/faculty/Stefan_Waner/RealWorld/calctopic1/regression.html>
+L<http://people.hofstra.edu/faculty/Stefan_Waner/RealWorld/calctopic1/regression.html>
 by Stefan Waner and Steven R. Costenoble.
 
 =head1 SEE ALSO
@@ -302,7 +302,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1997-2015 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
