@@ -81,7 +81,7 @@ Also uses environment variable TMPDIR, if -T is
 not specified.
 Default is /tmp.
 
-=item B<--parallelism> N
+=item B<--parallelism N> or B<-j N>
 
 Allow up to N merges to happen in parallel.
 Default is the number of CPUs in the machine.
@@ -288,9 +288,9 @@ sub parse_options($@) {
 	'endgame!' => \$self->{_endgame},
 	'i|input=s@' => sub { $self->parse_io_option('inputs', @_); },
 	'inputs!' => \$past_sort_options,
+	'j|parallelism=i' => \$self->{_max_parallelism},
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
-	'parallelism=i' => \$self->{_max_parallelism},
 	'removeinputs!' => \$self->{_remove_inputs},
 	'test=s' => \$self->{_test},
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
