@@ -69,6 +69,11 @@ but Fsdb::Filter objects in Perl do not run until you invoke
 the run() method.
 The C<--(no)autorun> option controls that behavior within Perl.
 
+=item B<--header> H
+
+Use H as the full Fsdb header, rather than reading a header from
+then input.
+
 =item B<--help>
 
 Show help.
@@ -161,6 +166,7 @@ sub set_defaults ($) {
     $self->SUPER::set_defaults();
     $self->{_invert_match} = undef;
     $self->{_warnings} = undef;
+    $self->{_header} = undef;
 }
 
 =head2 parse_options
@@ -182,6 +188,7 @@ sub parse_options ($@) {
 	'autorun!' => \$self->{_autorun},
 	'close!' => \$self->{_close},
 	'd|debug+' => \$self->{_debug},
+	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
@@ -202,7 +209,9 @@ Internal: setup, parse headers.
 sub setup ($) {
     my($self) = @_;
 
-    $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub);
+    my(@in_options) = (-comment_handler => $self->create_pass_comments_sub);
+    push(@in_options, -header => $self->{_header}) if (defined($self->{_header}));
+    $self->finish_io_option('input', @in_options);
     my $read_fastpath_sub = $self->{_in}->fastpath_sub();
 
     $self->finish_io_option('output', -clone => $self->{_in});
