@@ -2,8 +2,7 @@
 
 #
 # dbrowuniq.pm
-# Copyright (C) 1997-2015 by John Heidemann <johnh@isi.edu>
-# $Id$
+# Copyright (C) 1997-2016 by John Heidemann <johnh@isi.edu>
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -115,6 +114,11 @@ but Fsdb::Filter objects in Perl do not run until you invoke
 the run() method.
 The C<--(no)autorun> option controls that behavior within Perl.
 
+=item B<--header> H
+
+Use H as the full Fsdb header, rather than reading a header from
+then input.
+
 =item B<--help>
 
 Show help.
@@ -279,6 +283,7 @@ sub set_defaults ($) {
     $self->{_incremental} = undef;
     $self->{_uniquifying_cols} = [];
     $self->{_destination_column} = 'count';
+    $self->{_header} = undef;
 }
 
 =head2 parse_options
@@ -301,6 +306,7 @@ sub parse_options ($@) {
 	'B|both' => sub { $self->{_which} = 'B' },
 	'c|count!' => \$self->{_count},
 	'F|first|nolast' => sub { $self->{_which} = 'F' },
+	'header=s' => \$self->{_header},
 	'I|incremental!' => \$self->{_incremental},
 	'L|last' => sub { $self->{_which} = 'L' },
 	'close!' => \$self->{_close},
@@ -324,7 +330,9 @@ Internal: setup, parse headers.
 sub setup ($) {
     my($self) = @_;
 
-    $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub);
+    my(@finish_args) = (-comment_handler => $self->create_pass_comments_sub);
+    push (@finish_args, -header => $self->{_header}) if (defined($self->{_header}));
+    $self->finish_io_option('input', @finish_args);
 
     if ($#{$self->{_uniquifying_cols}} == -1) {
 	foreach (@{$self->{_in}->cols}) {
@@ -441,7 +449,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1997-2015 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1997-2016 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
