@@ -31,7 +31,7 @@ The sort should be stable, but this has not yet been verified.
 
 For large inputs (those that spill to disk),
 L<dbsort> will do some of the merging in parallel, if possible.
-The <--parallel> option can control the degree of parallelism,
+The B<--parallel> option can control the degree of parallelism,
 if desired.
 
 =head1 OPTIONS
@@ -53,7 +53,7 @@ Also uses environment variable TMPDIR, if -T is
 not specified.
 Default is /tmp.
 
-=item <--parallelism> N
+=item B<--parallelism N> or B<-j N>  
 
 Allow up to N merges to happen in parallel.
 Default is the number of CPUs in the machine.
@@ -110,7 +110,7 @@ but Fsdb::Filter objects in Perl do not run until you invoke
 the run() method.
 The C<--(no)autorun> option controls that behavior within Perl.
 
-=item B<--header> H
+=item B<--header H>
 
 Use H as the full Fsdb header, rather than reading a header from
 then input.
@@ -238,10 +238,10 @@ sub parse_options ($@) {
 	'd|debug+' => \$self->{_debug},
 	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
+	'j|parallelism=i' => \$self->{_max_parallelism},
 	'log!' => \$self->{_logprog},
 	'M|maxmemory=i' => \$self->{_max_memory},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
-	'parallelism=i' => \$self->{_max_parallelism},
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
 	# sort key options:
 	'n|numeric' => sub { $self->parse_sort_option(@_); },
