@@ -3,7 +3,7 @@
 #
 # xml_to_db.pm
 # Copyright (C) 2011-2015 by John Heidemann <johnh@isi.edu>
-# $Id$
+# $Id: 54d87bcf09ffd487550f0f7e05ab0a77cf2a3670 $
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -114,7 +114,11 @@ end_standard_fsdb_options
 
 =head2 Output:
 
-	xxx
+	#fsdb -F S addtime album artist title
+	3389919728  Born to Pick  7th Day Buskers  Loch Lamor
+	3389919728  Born to Pick  7th Day Buskers  The Floods
+	3389919735  Copland Conducts Copland  Aaron Copland  Our Town
+	#   | xml_to_db -k files/file
 
 =head1 SEE ALSO
 
