@@ -2,7 +2,7 @@
 
 #
 # Fsdb::IO.pm
-# $Id$
+# $Id: dac8ca3b6f469025184776b4fd18db3ba3c9b4a0 $
 #
 # Copyright (C) 2005-2013 by John Heidemann <johnh@isi.edu>
 #
@@ -760,6 +760,8 @@ sub correct_fref_containing_fs {
     $fscode = $fsdb->fscode;
 
 Returns the fscode of the given database.
+(The encoded verison representing the field separator.)
+See also fs to get the actual field separator.
 
 =cut
 
@@ -768,6 +770,20 @@ sub fscode {
     return $self->{_fscode};
 }
 
+=head2 fs
+
+    $fscode = $fsdb->fs;
+
+Returns the field separator.
+See C<fscode> to get the "encoded" version.
+
+=cut
+
+sub fs {
+    my($self) = @_;
+    return $self->{_fs};
+}
+
 
 =head2 rscode
 
