@@ -93,6 +93,12 @@ where the one argument will be a string with the unparsed comment
 
 By default, or if $ref is undef, comments are consumed.
 
+A typical handler if you have an output Fsdb stream is:
+
+    sub { $out->write_raw(@_); };
+
+(That is the code created by  L<Fsdb::Filter::create_pass_comments_sub>.)
+
 There are several support routines to handle comments in a pipeline;
 see L<Fsdb::Filter::create_pass_comments_sub>,
 L<Fsdb::Filter::create_tolerant_pass_comments_sub>,
