@@ -31,6 +31,7 @@ This class contains the bits of Fsdb::Old that needed to be kept.
 use Exporter 'import';
 @EXPORT = qw();
 @EXPORT_OK = qw(
+    shell_quote
     code_prettify
     force_numeric
     fullname_to_sortkey
@@ -103,6 +104,21 @@ sub code_prettify (@) {
     return $prettycode;
 }
 
+=head2 shell_quote
+
+Convert output to shell-like quoting
+
+=cut
+sub shell_quote(@) {
+    my($s) = @_;
+    if ($s =~ /\s/) {
+	# should use String::ShellQuote, but don't want the dpeendency
+	$s =~ s/\'/'\\\''/g;
+	$s = "'" . $s . "'";
+    };
+    return $s;
+}
+
 =head1 CONVERSION FUNCTIONS
 
 =head2 number_prettify 
